@@ -15,11 +15,11 @@ Test::Dependencies - Ensure that the dependency listing is complete
 
 =head1 VERSION
 
-Version 0.29
+Version 0.31
 
 =cut
 
-our $VERSION = '0.29';
+our $VERSION = '0.31';
 
 =head1 SYNOPSIS
 
@@ -119,7 +119,9 @@ sub _get_modules_used_in_file {
     my $p = Pod::Strip->new;
     $p->output_string(\$code);
     $p->parse_string_document($data);
-    $used{$2}++ while $code =~ /^\s*(use|with|extends)\s+['"]?([\w:]+)['"]?/gm;
+    $code =~ m/^(__DATA__|__END__)$.*/m
+        and $code = $`; # strip data and end sections ($`==$PREMATCH)
+    $used{$2}++ while $code =~ /^\s*(use|with|extends)\s+['"]?([\w:.]+)['"]?/gm;
     while ($code =~ m{^\s*use\s+base
                           \s+(?:qw.|(?:(?:['"]|q.|qq.)))([\w\s:]+)}gmx) {
         $used{$_}++ for split ' ', $1;
@@ -148,12 +150,8 @@ sub _legacy_ok_dependencies {
     {
         local $@;
 
-        eval {
-            use CPAN::Meta;
-        };
-        eval {
-            use File::Find::Rule::Perl;
-        };
+        eval "use CPAN::Meta;";
+        eval "use File::Find::Rule::Perl;";
 
         $missing_dep = $@;
     }
@@ -304,6 +302,7 @@ sub ok_dependencies {
 
     foreach my $mod (sort keys %used) {
         next if ($mod =~ $ignores_re
+                 or $mod =~ m/^v?\d+[.]\d+/  # minimum perl version requirement
                  or ($exclude_re and  $mod =~ $exclude_re));
 
         my $first_in = Module::CoreList->first_release($mod, $required{$mod});
@@ -382,7 +381,7 @@ L<http://search.cpan.org/dist/Test-Dependencies>
 
 =head1 LICENCE AND COPYRIGHT
 
-    Copyright (c) 2016-2020, Erik Huelsmann. All rights reserved.
+    Copyright (c) 2016-2023, Erik Huelsmann. All rights reserved.
     Copyright (c) 2007, Best Practical Solutions, LLC. All rights reserved.
 
     This module is free software; you can redistribute it and/or modify it
